aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/gl/GrGLCaps.h
diff options
context:
space:
mode:
authorGravatar Brian Salomon <bsalomon@google.com>2017-06-12 10:24:42 -0400
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2017-06-12 14:46:20 +0000
commit6d9c88bd6ad28d8869f81131bcc4620f65c222cc (patch)
treec23f311fa6f19134e236e55b32d74537062d7d3b /src/gpu/gl/GrGLCaps.h
parentce9514c6cd91c7225ec0d7ccfffd1d964cb1ac6a (diff)
Modify Adreno 3xx workaround to toggle face culling rather than call glFlush.
This fixes some correctness issues introduced by the previous workaround in MSAA gm images. It hopefully improves performance regressions introduced in MSAA benchmarks from calling glFlush. A comment on the workaround is updated to indicate that the original line-drop-out bug was seen on the N5 running driver 127.0. It simply showed up in different GMs that on the N7 running 127.0 Bug: skia:6755 Change-Id: Ief066fd9b223c043a80e7fe07ff13aac07a48970 Reviewed-on: https://skia-review.googlesource.com/19481 Reviewed-by: Brian Osman <brianosman@google.com> Commit-Queue: Brian Salomon <bsalomon@google.com>
Diffstat (limited to 'src/gpu/gl/GrGLCaps.h')
-rw-r--r--src/gpu/gl/GrGLCaps.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gpu/gl/GrGLCaps.h b/src/gpu/gl/GrGLCaps.h
index 4fb8b7104f..7d81d23481 100644
--- a/src/gpu/gl/GrGLCaps.h
+++ b/src/gpu/gl/GrGLCaps.h
@@ -374,10 +374,10 @@ public:
/// op instead of using glClear seems to resolve the issue.
bool useDrawToClearStencilClip() const { return fUseDrawToClearStencilClip; }
- // At least some Adreno 3xx drivers draw lines incorrectly if there is not a flush after
- // non-line draws under some not fully understood circumstances.
- bool requiresFlushToDrawLinesAfterNonLines() const {
- return fRequiresFlushToDrawLinesAfterNonLines;
+ // At least some Adreno 3xx drivers draw lines incorrectly after drawing non-lines. Toggling
+ // face culling on and off seems to resolve this.
+ bool requiresCullFaceEnableDisableWhenDrawingLinesAfterNonLines() const {
+ return fRequiresCullFaceEnableDisableWhenDrawingLinesAfterNonLines;
}
bool initDescForDstCopy(const GrRenderTargetProxy* src, GrSurfaceDesc* desc,
@@ -456,7 +456,7 @@ private:
bool fClearTextureSupport : 1;
bool fDrawArraysBaseVertexIsBroken : 1;
bool fUseDrawToClearStencilClip : 1;
- bool fRequiresFlushToDrawLinesAfterNonLines : 1;
+ bool fRequiresCullFaceEnableDisableWhenDrawingLinesAfterNonLines : 1;
uint32_t fBlitFramebufferFlags;